/*
 * Copyright Openmind http://www.openmindonline.it
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package it.openutils.spring.context;

import org.springframework.web.context.WebApplicationContext;


/**
 * Holder class to expose the web application context in the form of a thread-bound {@link WebApplicationContext}
 * object.
 * <p>
 * Use {@link WebApplicationContextListener} to expose the current application context.
 * @author Fabrizio Giustina
 * @version $Id: WebApplicationContextHolder.java 527 2008-01-14 12:01:09Z fgiust $
 */
public final class WebApplicationContextHolder
{

    private static ThreadLocal<WebApplicationContext> tl = new ThreadLocal<WebApplicationContext>();

    /**
     * Don't instantiate.
     */
    private WebApplicationContextHolder()
    {
        // unused
    }

    /**
     * Returns the thread-bound WebApplicationContext.
     * @return WebApplicationContext
     */
    public static WebApplicationContext get()
    {
        return tl.get();
    }

    /**
     * Bind a WebApplicationContext to the current thread.
     * @param webApplicationContext WebApplicationContext
     */
    public static void set(WebApplicationContext webApplicationContext)
    {
        tl.set(webApplicationContext);
    }
}
