/*
 * Copyright Openmind http://www.openmindonline.it
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package it.openutils.spring.context;

import javax.servlet.ServletRequestEvent;
import javax.servlet.ServletRequestListener;

import org.springframework.web.context.WebApplicationContext;
import org.springframework.web.context.support.WebApplicationContextUtils;


/**
 * Listener for Servlet 2.4+ containers. Exposes the web application context to the current thread, through
 * WebApplicationContextHolder. To be registered as listener in <code>web.xml</code>.
 * @author Fabrizio Giustina
 * @version $Id: WebApplicationContextListener.java 527 2008-01-14 12:01:09Z fgiust $
 */
public class WebApplicationContextListener implements ServletRequestListener
{

    /**
     * {@inheritDoc}
     */
    public void requestInitialized(ServletRequestEvent sre)
    {
        WebApplicationContext wac = WebApplicationContextUtils.getWebApplicationContext(sre.getServletContext());
        WebApplicationContextHolder.set(wac);
    }

    /**
     * {@inheritDoc}
     */
    public void requestDestroyed(ServletRequestEvent sre)
    {
        WebApplicationContextHolder.set(null);
    }

}
