package it.openutils.spring.email;

import java.io.File;
import java.io.IOException;

import javax.mail.MessagingException;
import javax.mail.internet.MimeMessage;
import javax.mail.internet.MimeMessage.RecipientType;

import org.apache.commons.io.FileUtils;
import org.apache.commons.lang.ArrayUtils;
import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringEscapeUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;


/**
 * @author fgiust
 * @version $Id: FileMessageStore.java 527 2008-01-14 12:01:09Z fgiust $
 */
public class FileMessageStore implements MessageStore
{

    /**
     * Logger.
     */
    private Logger log = LoggerFactory.getLogger(FileMessageStore.class);

    private String outputDirectory;

    /**
     * Sets the outputDirectory.
     * @param outputDirectory the outputDirectory to set
     */
    public void setOutputDirectory(String outputDirectory)
    {
        this.outputDirectory = outputDirectory;
    }

    /**
     * {@inheritDoc}
     */
    public void saveMessage(MimeMessage message, String template)
    {
        File dir = new File(outputDirectory);
        dir.mkdirs();
        File file = new File(dir, template + "." + System.currentTimeMillis() + ".html");

        StringBuffer buffer = new StringBuffer();

        try
        {
            buffer.append("From: ");
            buffer.append(StringEscapeUtils.escapeXml(ArrayUtils.toString(message.getFrom())));
            buffer.append("\n");

            if (message.getReplyTo() != null)
            {
                buffer.append("Reply-to: ");
                buffer.append(StringEscapeUtils.escapeXml(ArrayUtils.toString(message.getReplyTo())));
                buffer.append("\n");
            }

            buffer.append("To: ");
            buffer.append(StringEscapeUtils.escapeXml(ArrayUtils.toString(message.getRecipients(RecipientType.TO))));
            buffer.append("\n");

            if (message.getRecipients(RecipientType.CC) != null)
            {
                buffer.append("CC: ");
                buffer
                    .append(StringEscapeUtils.escapeXml(ArrayUtils.toString(message.getRecipients(RecipientType.CC))));
                buffer.append("\n");
            }

            if (message.getRecipients(RecipientType.BCC) != null)
            {
                buffer.append("BCC: ");
                buffer.append(StringEscapeUtils
                    .escapeXml(ArrayUtils.toString(message.getRecipients(RecipientType.BCC))));
                buffer.append("\n");
            }
            buffer.append("\n");

            buffer.append(ObjectUtils.toString(message.getContent()));

            FileUtils.writeStringToFile(file, buffer.toString());
        }
        catch (MessagingException e)
        {
            log.error(e.getMessage(), e);
        }
        catch (IOException e)
        {
            log.error(e.getMessage(), e);
        }
    }

}
