/*
 * Copyright Openmind http://www.openmindonline.it
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package it.openutils.web.spring;

import java.text.NumberFormat;

import org.apache.commons.lang.StringUtils;
import org.springframework.beans.propertyeditors.CustomNumberEditor;


/**
 * Convenience double custom editor which allows to use both "." and "," as decimal separators.
 * @author fgiust
 * @version $Revision$ ($Author$)
 */
public class EasyDoubleCustomEditor extends CustomNumberEditor
{

    /**
     * @param numberClass
     * @param allowEmpty
     * @throws IllegalArgumentException
     */
    public EasyDoubleCustomEditor(Class< ? extends Number> numberClass, boolean allowEmpty)
        throws IllegalArgumentException
    {
        super(numberClass, allowEmpty);
    }

    /**
     * @param numberClass
     * @param numberFormat
     * @param allowEmpty
     * @throws IllegalArgumentException
     */
    public EasyDoubleCustomEditor(Class< ? extends Number> numberClass, NumberFormat numberFormat, boolean allowEmpty)
        throws IllegalArgumentException
    {
        super(numberClass, numberFormat, allowEmpty);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void setAsText(String text) throws IllegalArgumentException
    {
        super.setAsText(StringUtils.replace(text, ",", "."));
    }

}
